@@ -21,6 +21,11 @@ if (!is.null(zd)) sealX@depth <- zd
 detd <- diveMove:::.detDive(getDepth(sealX), detp[[2]], 4)
 ###_ : Check labelling of dive phases
 phaselabs <- diveMove:::.labDivePhase(sealX, detd[, 1], smooth.par=0.1,
+                                      dive.model="smooth.spline",
+                                      knot.factor=3, descent.crit.q=0,
+                                      ascent.crit.q=0.1)
+phaselabs <- diveMove:::.labDivePhase(sealX, detd[, 1], smooth.par=0.1,
+                                      dive.model="unimodal",
                                       knot.factor=3, descent.crit.q=0,
                                       ascent.crit.q=0.1)
 
